@@ -34,5 +34,11 @@ class ReadOnly(BasePermission):
     def has_permission(self, request, view):
         return request.method in SAFE_METHODS
 
+class IsEmailVerified(BasePermission):
+    def has_permission(self, request, view):
+        user = request.user
+        email_address = user.emailaddress_set.get(email=user.email)
+        return email_address.verified
+
 
 
