@@ -20,12 +20,13 @@ def is_anonymous_user(user):
 def changelist_no_args(action_name, model):
     def decorator(function):
         def wrapper(self, request, *args, **kwargs):
-            if 'action' in request.POST and request.POST['action'] == action_name:
-                if not request.POST.getlist(ACTION_CHECKBOX_NAME):
-                    post = request.POST.copy()
-                    for u in model.objects.all():
-                        post.update({ACTION_CHECKBOX_NAME: str(u.id)})
-                    request._set_post(post)
+            if 'action' in request.POST:
+                if (type(action_name) == list and request.POST['action'] in action_name) or request.POST['action'] == action_name:
+                    if not request.POST.getlist(ACTION_CHECKBOX_NAME):
+                        post = request.POST.copy()
+                        for u in model.objects.all():
+                            post.update({ACTION_CHECKBOX_NAME: str(u.id)})
+                        request._set_post(post)
             function(self, request, *args, **kwargs)
             return super(self.__class__, self).changelist_view(request, *args, **kwargs)
         return wrapper
